import { listHelpers } from 'redux-admin';
import { getDeepObjectValue } from 'validate.js';
import startCase from 'lodash/startCase';
var EMPTY_OBJ = {};

var getListFields = function getListFields(props) {
  var jsonSchema = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

  var properties = jsonSchema.properties || EMPTY_OBJ;
  var fields = [];
  Object.keys(properties).forEach(function (itemKey) {
    var item = properties[itemKey];
    var meta = getDeepObjectValue(item, 'meta.0') || EMPTY_OBJ;
    if ((item.type === 'object' || item.type === Object) && meta === EMPTY_OBJ) {
      // in this case the meta can be found at the children as parentDashboard, this is a workaround;
      var metaFromInnerField = void 0;
      Object.keys(item.properties).forEach(function (itemKey) {
        if (!metaFromInnerField) {
          var innerField = item.properties[itemKey];
          metaFromInnerField = getDeepObjectValue(innerField, 'meta.0.parentDashboard');
        }
      });
      if (metaFromInnerField) {
        meta = { dashboard: metaFromInnerField };
      }
    }
    var dashboard = getDeepObjectValue(meta, 'dashboard') || EMPTY_OBJ;
    var dashboardList = getDeepObjectValue(meta, 'dashboard.list') || EMPTY_OBJ;
    var type = item.type;
    if (item.format === 'date-time') type = Date;
    if (meta.ref) {
      type = Object;
    }
    if (dashboard.hide) return null;
    if (dashboardList.hide) return null;
    var fieldConfig = {
      key: itemKey,
      title: dashboardList.label || dashboard.label || startCase(itemKey),
      type: dashboardList.type || type,
      sorter: dashboardList.sorter === false ? false : dashboardList.sorter || true,
      width: dashboardList.width,
      labelKey: meta.displayKey
    };
    fields.push(listHelpers.getListField(fieldConfig));
  });
  return fields;
};
export default getListFields;