'use strict';

exports.__esModule = true;

var _reduxAdmin = require('redux-admin');

var _validate = require('validate.js');

var _startCase = require('lodash/startCase');

var _startCase2 = _interopRequireDefault(_startCase);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var EMPTY_OBJ = {};

var getListFields = function getListFields(props) {
  var jsonSchema = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

  var properties = jsonSchema.properties || EMPTY_OBJ;
  var fields = [];
  Object.keys(properties).forEach(function (itemKey) {
    var item = properties[itemKey];
    var meta = (0, _validate.getDeepObjectValue)(item, 'meta.0') || EMPTY_OBJ;
    if ((item.type === 'object' || item.type === Object) && meta === EMPTY_OBJ) {
      // in this case the meta can be found at the children as parentDashboard, this is a workaround;
      var metaFromInnerField = void 0;
      Object.keys(item.properties).forEach(function (itemKey) {
        if (!metaFromInnerField) {
          var innerField = item.properties[itemKey];
          metaFromInnerField = (0, _validate.getDeepObjectValue)(innerField, 'meta.0.parentDashboard');
        }
      });
      if (metaFromInnerField) {
        meta = { dashboard: metaFromInnerField };
      }
    }
    var dashboard = (0, _validate.getDeepObjectValue)(meta, 'dashboard') || EMPTY_OBJ;
    var dashboardList = (0, _validate.getDeepObjectValue)(meta, 'dashboard.list') || EMPTY_OBJ;
    var type = item.type;
    if (item.format === 'date-time') type = Date;
    if (meta.ref) {
      type = Object;
    }
    if (dashboard.hide) return null;
    if (dashboardList.hide) return null;
    var fieldConfig = {
      key: itemKey,
      title: dashboardList.label || dashboard.label || (0, _startCase2.default)(itemKey),
      type: dashboardList.type || type,
      sorter: dashboardList.sorter === false ? false : dashboardList.sorter || true,
      width: dashboardList.width,
      labelKey: meta.displayKey
    };
    fields.push(_reduxAdmin.listHelpers.getListField(fieldConfig));
  });
  return fields;
};
exports.default = getListFields;
module.exports = exports['default'];